@@ -34,23 +34,25 @@ Q_DECLARE_METATYPE(InhibitionInfo)
 
 PowerManagementInhibition::PowerManagementInhibition(QObject *parent)
     : QObject(parent)
-    , m_solidPowerServiceWatcher(new QDBusServiceWatcher(s_solidPowerService, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration | QDBusServiceWatcher::WatchForRegistration))
+    , m_solidPowerServiceWatcher(new QDBusServiceWatcher(s_solidPowerService,
+                                                         QDBusConnection::sessionBus(),
+                                                         QDBusServiceWatcher::WatchForUnregistration | QDBusServiceWatcher::WatchForRegistration))
 {
     qDBusRegisterMetaType<QList<InhibitionInfo>>();
     qDBusRegisterMetaType<InhibitionInfo>();
 
-    connect(m_solidPowerServiceWatcher, &QDBusServiceWatcher::serviceUnregistered, this,
-        [this] {
-            m_serviceRegistered = false;
-            m_inhibited = false;
-            QDBusConnection::sessionBus().disconnect(s_solidPowerService, s_solidPath, s_solidPowerService,
-                                                     QStringLiteral("InhibitionsChanged"),
-                                                     this, SLOT(inhibitionsChanged(QList<InhibitionInfo>,QStringList)));
-        }
-    );
+    connect(m_solidPowerServiceWatcher, &QDBusServiceWatcher::serviceUnregistered, this, [this] {
+        m_serviceRegistered = false;
+        m_inhibited = false;
+        QDBusConnection::sessionBus().disconnect(s_solidPowerService,
+                                                 s_solidPath,
+                                                 s_solidPowerService,
+                                                 QStringLiteral("InhibitionsChanged"),
+                                                 this,
+                                                 SLOT(inhibitionsChanged(QList<InhibitionInfo>, QStringList)));
+    });
     connect(m_solidPowerServiceWatcher, &QDBusServiceWatcher::serviceRegistered, this, &PowerManagementInhibition::update);
 
-
     // check whether the service is registered
     QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.DBus"),
                                                           QStringLiteral("/"),
@@ -58,18 +60,16 @@ PowerManagementInhibition::PowerManagementInhibition(QObject *parent)
                                                           QStringLiteral("ListNames"));
     QDBusPendingReply<QStringList> async = QDBusConnection::sessionBus().asyncCall(message);
     QDBusPendingCallWatcher *callWatcher = new QDBusPendingCallWatcher(async, this);
-    connect(callWatcher, &QDBusPendingCallWatcher::finished, this,
-        [this](QDBusPendingCallWatcher *self) {
-            QDBusPendingReply<QStringList> reply = *self;
-            self->deleteLater();
-            if (!reply.isValid()) {
-                return;
-            }
-            if (reply.value().contains(s_solidPowerService)) {
-                update();
-            }
+    connect(callWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *self) {
+        QDBusPendingReply<QStringList> reply = *self;
+        self->deleteLater();
+        if (!reply.isValid()) {
+            return;
         }
-    );
+        if (reply.value().contains(s_solidPowerService)) {
+            update();
+        }
+    });
 }
 
 PowerManagementInhibition::~PowerManagementInhibition() = default;
@@ -77,9 +77,12 @@ PowerManagementInhibition::~PowerManagementInhibition() = default;
 void PowerManagementInhibition::update()
 {
     m_serviceRegistered = true;
-    QDBusConnection::sessionBus().connect(s_solidPowerService, s_solidPath, s_solidPowerService,
+    QDBusConnection::sessionBus().connect(s_solidPowerService,
+                                          s_solidPath,
+                                          s_solidPowerService,
                                           QStringLiteral("InhibitionsChanged"),
-                                          this, SLOT(inhibitionsChanged(QList<InhibitionInfo>,QStringList)));
+                                          this,
+                                          SLOT(inhibitionsChanged(QList<InhibitionInfo>, QStringList)));
     checkInhibition();
 }
 
@@ -92,21 +95,16 @@ void PowerManagementInhibition::inhibitionsChanged(const QList<InhibitionInfo> &
 
 void PowerManagementInhibition::checkInhibition()
 {
-    QDBusMessage msg = QDBusMessage::createMethodCall(s_solidPowerService,
-                                                      s_solidPath,
-                                                      s_solidPowerService,
-                                                      QStringLiteral("HasInhibition"));
-    msg << (uint) 5; // PowerDevil::PolicyAgent::RequiredPolicy::ChangeScreenSettings | PowerDevil::PolicyAgent::RequiredPolicy::InterruptSession
+    QDBusMessage msg = QDBusMessage::createMethodCall(s_solidPowerService, s_solidPath, s_solidPowerService, QStringLiteral("HasInhibition"));
+    msg << (uint)5; // PowerDevil::PolicyAgent::RequiredPolicy::ChangeScreenSettings | PowerDevil::PolicyAgent::RequiredPolicy::InterruptSession
     QDBusPendingReply<bool> pendingReply = QDBusConnection::sessionBus().asyncCall(msg);
     QDBusPendingCallWatcher *callWatcher = new QDBusPendingCallWatcher(pendingReply, this);
-    connect(callWatcher, &QDBusPendingCallWatcher::finished, this,
-        [this](QDBusPendingCallWatcher *self) {
-            QDBusPendingReply<bool> reply = *self;
-            self->deleteLater();
-            if (!reply.isValid()) {
-                return;
-            }
-            m_inhibited = reply.value();
+    connect(callWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *self) {
+        QDBusPendingReply<bool> reply = *self;
+        self->deleteLater();
+        if (!reply.isValid()) {
+            return;
         }
-    );
+        m_inhibited = reply.value();
+    });
 }
