@@ -17,7 +17,7 @@ Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public
 License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
-#include "../powermanagement.h"
+#include "../greeter/powermanagement.h"
 #include <QGuiApplication>
 #include <QQmlContext>
 #include <QQuickView>
